# ft_toolbox  
  
## installation  
  
```shell  
pip install fttb
```  
  
## usage  
  
### use command  
  
use latest version of clion:  
  
```shell  
python -m fttb use clion
```  
  
use version 2023.1 of clion:  
  
```shell  
python -m fttb use clion 2023.1
```  
  
  
### list command  
  
list all available ides:  
  
```shell  
python -m fttb list
```  
  
list all available versions of pycharm:  
  
```shell  
python -m fttb list pycharm
```  
  
  
### links  
  
[pypi page](https://pypi.org/project/fttb/)
